function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var styles = {"dataframe":"_2uSta","input_prompt":"_R3qoq","output_prompt":"_2Uqcj","output_stderr":"_RMCAr","ansi_black_fg":"_2l_MQ","ansi_red_fg":"_2bmOe","ansi_green_fg":"_KAjmd","ansi_yellow_fg":"_2Ai70","ansi_blue_fg":"_1cvmp","ansi_magenta_fg":"_1FCJ1","ansi_cyan_fg":"_2O1-i","ansi_white_fg":"_2Iaa9"};

var base64ToImage = function base64ToImage(mime, base64) {
  return React__default.createElement("img", {
    src: "data:" + mime + ";base64," + base64
  });
};

function getDataFrame(raw) {
  var rows = raw.split('\n');
  var elements = rows.map(function (r) {
    return r.split('  ');
  });
  return React__default.createElement("table", {
    className: "dataframe " + styles.dataframe
  }, React__default.createElement("thead", null, React__default.createElement("tr", null, React__default.createElement("td", null), elements[0].slice(1).map(function (h, hidx) {
    return React__default.createElement("th", {
      key: hidx,
      scope: "col"
    }, h);
  }))), React__default.createElement("tbody", null, elements.slice(1).map(function (row, rowidx) {
    return React__default.createElement("tr", {
      key: rowidx
    }, React__default.createElement("th", {
      scope: "row"
    }, row[0]), row.slice(1).map(function (d, idx) {
      return React__default.createElement("td", {
        key: idx
      }, d);
    }));
  })));
}

var DisplayDataOutput = function DisplayDataOutput(_ref) {
  var output = _ref.output;
  var datas = output.data;
  var formats = ['text/html', 'image/svg+xml', 'image/png', 'image/jpeg', 'text/plain'];

  if (formats[0] in datas && formats[4] in datas) {
    return getDataFrame(datas[formats[4]].join(''));
  }

  for (var _i = 0, _formats = formats; _i < _formats.length; _i++) {
    var format = _formats[_i];

    if (format in datas) {
      var datalines = datas[format];

      if (format === 'image/svg+xml') {
        var svg = datalines.join('');
        return React__default.createElement("img", {
          src: "data:image/svg+xml;utf8," + svg
        });
      }

      if (format === 'text/html') return React__default.createElement("iframe", {
        srcDoc: datalines.join('')
      });

      if (format.startsWith('image/')) {
        if (Array.isArray(datalines)) return base64ToImage(format, datalines[0]);
        return base64ToImage(format, datalines);
      }

      return React__default.createElement("pre", null, React__default.createElement("code", null, datalines.join('')));
    }
  }

  throw new Error('Unsupported output format');
};

var StreamOutput = function StreamOutput(_ref2) {
  var output = _ref2.output;
  var className = "output_stream " + styles.output_stream + " " + (output.name === 'stderr' ? "output_stderr " + styles.output_stderr : '');
  return React__default.createElement("div", {
    className: className
  }, React__default.createElement("pre", null, output.text.join('')));
};

var ansiClassNames = {
  30: "ansi_black_fg " + styles.ansi_black_fg,
  31: "ansi_red_fg " + styles.ansi_red_fg,
  32: "ansi_green_fg " + styles.ansi_green_fg,
  33: "ansi_yellow_fg " + styles.ansi_yellow_fg,
  34: "ansi_blue_fg " + styles.ansi_blue_fg,
  35: "ansi_magenta_fg " + styles.ansi_magenta_fg,
  36: "ansi_cyan_fg " + styles.ansi_cyan_fg,
  37: "ansi_white_fg " + styles.ansi_white_fg
};

function ansiCodeToClassName(ansiCode) {
  var codes = ansiCode.slice(2, -1).split(';');
  if (codes === ['0']) return null;
  return codes.map(function (c) {
    return ansiClassNames[c];
  }).join(' ');
}

var ErrorOutput = function ErrorOutput(_ref3) {
  var output = _ref3.output;
  var r = /(\x1b\[.+?m)/g;
  var traceback = output.traceback.join('');
  var splitted = traceback.split(r);
  var spans = [];
  var lastClassName = null;
  splitted.forEach(function (s, i) {
    if (r.test(s)) {
      lastClassName = ansiCodeToClassName(s);
      return;
    }

    if (!lastClassName) spans.push(s);else spans.push(React__default.createElement("span", {
      className: lastClassName,
      key: i
    }, s));
  });
  return React__default.createElement("pre", null, spans);
};

var CodeCell = function CodeCell(_ref4) {
  var cell = _ref4.cell,
      props = _objectWithoutPropertiesLoose(_ref4, ["cell"]);

  var source = cell.source.join('');
  return React__default.createElement(React.Fragment, null, React__default.createElement("tr", null, React__default.createElement("td", {
    className: "input_prompt " + styles.input_prompt
  }, React__default.createElement("pre", null, "In [" + (cell.execution_count || ' ') + "]:")), React__default.createElement("td", null, React__default.createElement(props.code, {
    language: props.language
  }, source))), cell.outputs.map(function (output, i) {
    return React__default.createElement("tr", {
      key: i
    }, React__default.createElement("td", {
      className: "output_prompt " + styles.output_prompt
    }, React__default.createElement("pre", null, output.output_type === 'execute_result' ? "Out[" + output.execution_count + "]:" : '')), React__default.createElement("td", null, function () {
      switch (output.output_type) {
        case 'execute_result':
        case 'display_data':
          return React__default.createElement(DisplayDataOutput, {
            output: output
          });

        case 'stream':
          return React__default.createElement(StreamOutput, {
            output: output
          });

        case 'error':
          return React__default.createElement(ErrorOutput, {
            output: output
          });

        default:
          return undefined;
      }
    }()));
  }));
};

function NbViewer(_ref5) {
  var _ipynb$metadata$kerne, _ipynb$metadata$langu;

  var source = _ref5.source,
      _ref5$markdown = _ref5.markdown,
      markdown = _ref5$markdown === void 0 ? PlainMarkdown : _ref5$markdown,
      _ref5$code = _ref5.code,
      code = _ref5$code === void 0 ? PlainCode : _ref5$code;
  if (!source) return null;
  var ipynb = typeof source === 'string' ? JSON.parse(source) : source;
  if (ipynb.nbformat !== 4) throw new Error('react-nbviewer currently supports nbformat 4 only');
  var language = ((_ipynb$metadata$kerne = ipynb.metadata.kernelspec) === null || _ipynb$metadata$kerne === void 0 ? void 0 : _ipynb$metadata$kerne.language) || ((_ipynb$metadata$langu = ipynb.metadata.language_info) === null || _ipynb$metadata$langu === void 0 ? void 0 : _ipynb$metadata$langu.name) || 'python';
  return React__default.createElement("table", null, React__default.createElement("tbody", null, ipynb.cells.map(function (cell, i) {
    return cell.cell_type === 'code' ? React__default.createElement(CodeCell, {
      cell: cell,
      language: language,
      code: code,
      key: i
    }) : React__default.createElement("tr", {
      key: i
    }, React__default.createElement("td", null), React__default.createElement("td", null, React__default.createElement(markdown, {
      source: cell.source.join(''),
      key: i
    }, null)));
  })));
}

function PlainMarkdown(props) {
  return React__default.createElement("div", null, props.source);
}

function PlainCode(props) {
  return React__default.createElement("pre", null, React__default.createElement("code", null, props.children));
}

module.exports = NbViewer;
//# sourceMappingURL=index.js.map
